@@ -37,9 +37,9 @@ def get_config_dir():
     """
     Return tmuxp configuration directory.
 
-    ``TMUXP_CONFIGDIR`` environmental variable has precedence if set. We also 
-    evaluate XDG default directory from XDG_CONFIG_HOME environmental variable 
-    if set or its default. Then the old default ~/.tmuxp is returned for 
+    ``TMUXP_CONFIGDIR`` environmental variable has precedence if set. We also
+    evaluate XDG default directory from XDG_CONFIG_HOME environmental variable
+    if set or its default. Then the old default ~/.tmuxp is returned for
     compatibility.
 
     Returns
@@ -399,6 +399,7 @@ def load_workspace(
     config_file,
     socket_name=None,
     socket_path=None,
+    new_session_name=None,
     colors=None,
     detached=False,
     answer_yes=False,
@@ -414,6 +415,8 @@ def load_workspace(
         ``tmux -L <socket-name>``
     socket_path: str, optional
         ``tmux -S <socket-path>``
+    new_session_name: str, options
+        ``tmux new -s <new_session_name>``
     colors : str, optional
         '-2'
             Force tmux to support 256 colors
@@ -498,6 +501,9 @@ def load_workspace(
     sconfig = sconfig.import_config(config_file).get()
     # shapes configurations relative to config / profile file location
     sconfig = config.expand(sconfig, os.path.dirname(config_file))
+    # Overwrite session name
+    if new_session_name:
+        sconfig['session_name'] = new_session_name
     # propagate config inheritance (e.g. session -> window, window -> pane)
     sconfig = config.trickle(sconfig)
 
@@ -606,7 +612,7 @@ def cli(log_level):
 
     Pass the "--help" argument to any command to see detailed help.
     See detailed documentation and examples at:
-    http://tmuxp.readthedocs.io/en/latest/"""
+    http://tmuxp.git-pull.com/"""
     try:
         has_minimum_version()
     except TmuxCommandNotFound:
@@ -659,7 +665,8 @@ def startup(config_dir):
 @click.argument('session_name', nargs=1, required=False)
 @click.option('-S', 'socket_path', help='pass-through for tmux -S')
 @click.option('-L', 'socket_name', help='pass-through for tmux -L')
-def command_freeze(session_name, socket_name, socket_path):
+@click.option('--force', 'force', help='overwrite the config file', is_flag=True)
+def command_freeze(session_name, socket_name, socket_path, force):
     """Snapshot a session into a config.
 
     If SESSION_NAME is provided, snapshot that session. Otherwise, use the
@@ -716,7 +723,7 @@ def command_freeze(session_name, socket_name, socket_path):
             dest_prompt = click.prompt(
                 'Save to: %s' % save_to, value_proc=get_abs_path, default=save_to
             )
-            if os.path.exists(dest_prompt):
+            if not force and os.path.exists(dest_prompt):
                 print('%s exists. Pick a new filename.' % dest_prompt)
                 continue
 
@@ -735,8 +742,8 @@ def command_freeze(session_name, socket_name, socket_path):
     else:
         print(
             'tmuxp has examples in JSON and YAML format at '
-            '<http://tmuxp.readthedocs.io/en/latest/examples.html>\n'
-            'View tmuxp docs at <http://tmuxp.readthedocs.io/>.'
+            '<http://tmuxp.git-pull.com/examples.html>\n'
+            'View tmuxp docs at <http://tmuxp.git-pull.com/>.'
         )
         sys.exit()
 
@@ -746,6 +753,7 @@ def command_freeze(session_name, socket_name, socket_path):
 @click.argument('config', type=ConfigPath(exists=True), nargs=-1)
 @click.option('-S', 'socket_path', help='pass-through for tmux -S')
 @click.option('-L', 'socket_name', help='pass-through for tmux -L')
+@click.option('-s', 'new_session_name', help='start new session with new session name')
 @click.option('--yes', '-y', 'answer_yes', help='yes', is_flag=True)
 @click.option(
     '-d', 'detached', help='Load the session without attaching it', is_flag=True
@@ -763,7 +771,16 @@ def command_freeze(session_name, socket_name, socket_path):
     flag_value=88,
     help='Like -2, but indicates that the terminal supports 88 colours.',
 )
-def command_load(ctx, config, socket_name, socket_path, answer_yes, detached, colors):
+def command_load(
+    ctx,
+    config,
+    socket_name,
+    socket_path,
+    new_session_name,
+    answer_yes,
+    detached,
+    colors,
+):
     """Load a tmux workspace from each CONFIG.
 
     CONFIG is a specifier for a configuration file.
@@ -791,6 +808,7 @@ def command_load(ctx, config, socket_name, socket_path, answer_yes, detached, co
     tmux_options = {
         'socket_name': socket_name,
         'socket_path': socket_path,
+        'new_session_name': new_session_name,
         'answer_yes': answer_yes,
         'colors': colors,
         'detached': detached,
@@ -809,7 +827,7 @@ def command_load(ctx, config, socket_name, socket_path, answer_yes, detached, co
         # Load each configuration but the last to the background
         for cfg in config[:-1]:
             opt = tmux_options.copy()
-            opt.update({'detached': True})
+            opt.update({'detached': True, 'new_session_name': None})
             load_workspace(cfg, **opt)
 
         # todo: obey the -d in the cli args only if user specifies
@@ -866,8 +884,8 @@ def import_config(configfile, importfunc):
     else:
         click.echo(
             'tmuxp has examples in JSON and YAML format at '
-            '<http://tmuxp.readthedocs.io/en/latest/examples.html>\n'
-            'View tmuxp docs at <http://tmuxp.readthedocs.io/>'
+            '<http://tmuxp.git-pull.com/examples.html>\n'
+            'View tmuxp docs at <http://tmuxp.git-pull.com/>'
         )
         sys.exit()
 
@@ -898,34 +916,36 @@ def command_import_tmuxinator(configfile):
 
 
 @cli.command(name='convert')
+@click.option(
+    '--yes', '-y', 'confirmed', help='Auto confirms with "yes".', is_flag=True
+)
 @click.argument('config', type=ConfigPath(exists=True), nargs=1)
-def command_convert(config):
+def command_convert(confirmed, config):
     """Convert a tmuxp config between JSON and YAML."""
 
     _, ext = os.path.splitext(config)
     if 'json' in ext:
-        if click.confirm('convert to <%s> to yaml?' % config):
-            configparser = kaptan.Kaptan()
-            configparser.import_config(config)
-            newfile = config.replace(ext, '.yaml')
-            newconfig = configparser.export('yaml', indent=2, default_flow_style=False)
-            if click.confirm('Save config to %s?' % newfile):
-                buf = open(newfile, 'w')
-                buf.write(newconfig)
-                buf.close()
-                print('New config saved to %s' % newfile)
+        to_filetype = 'yaml'
     elif 'yaml' in ext:
-        if click.confirm('convert to <%s> to json?' % config):
-            configparser = kaptan.Kaptan()
-            configparser.import_config(config)
-            newfile = config.replace(ext, '.json')
-            newconfig = configparser.export('json', indent=2)
-            print(newconfig)
-            if click.confirm('Save config to <%s>?' % newfile):
-                buf = open(newfile, 'w')
-                buf.write(newconfig)
-                buf.close()
-                print('New config saved to <%s>.' % newfile)
+        to_filetype = 'json'
+
+    configparser = kaptan.Kaptan()
+    configparser.import_config(config)
+    newfile = config.replace(ext, '.%s' % to_filetype)
+
+    export_kwargs = {'default_flow_style': False} if to_filetype == 'yaml' else {}
+    newconfig = configparser.export(to_filetype, indent=2, **export_kwargs)
+
+    if not confirmed:
+        if click.confirm('convert to <%s> to %s?' % (config, to_filetype)):
+            if click.confirm('Save config to %s?' % newfile):
+                confirmed = True
+
+    if confirmed:
+        buf = open(newfile, 'w')
+        buf.write(newconfig)
+        buf.close()
+        print('New config saved to <%s>.' % newfile)
 
 
 @cli.command(
